@@ -3,7 +3,7 @@ package Nagios::Plugin::CheckHost;
 use strict;
 use warnings;
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 our $URL = 'https://check-host.net/';
 
 use Net::CheckHost;
@@ -55,6 +55,12 @@ sub run {
     $self->process_check_result($result);
 }
 
+sub _result_class {
+    my ($self, $type) = @_;
+
+    "Nagios::Plugin::CheckHost::Result::" . ucfirst($type)
+}
+
 sub _check {
     my ($self, $type, $host, %args) = @_;
 
@@ -72,8 +78,7 @@ sub _check {
         my $rid = $check->{request_id};
         $self->{request_id} = $rid;
 
-        my $result_class =
-          "Nagios::Plugin::CheckHost::Result::" . ucfirst($type);
+        my $result_class = $self->_result_class($type);
         load_class($result_class);
         $result = $result_class->new(%$result_args,
             nodes => $self->nodes_class($check->{nodes}));
@@ -83,13 +88,17 @@ sub _check {
             sleep $self->{delay};
             $result->store_result(
                 $self->{checkhost}->request("check-result/$rid"));
-          } while ($start - time() < $self->{max_waittime}
+          } while (time() - $start < $self->{max_waittime}
             && $result->unfinished_nodes);
     }
     catch {
         $self->{nagios}->die($_);
     };
 
+    $result->remove_unfinished_nodes;
+    $self->{nagios}->die("No check results. Report " . $self->report_url)
+      unless $result->nodes;
+
     return $result;
 }
 
